<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compresseur?lang_cible=en
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// E
	'explication_url_statique_ressources' => 'A URL that can serve static files (images, JS ...) without cookie. Usually an alternative subdomain that also points to the site.',

	// I
	'info_compresseur_titre' => 'Optimisation and compression',
	'info_question_activer_compactage_css' => 'CSS',
	'info_question_activer_compactage_js' => 'Scripts',
	'item_compresseur_closure' => 'Use Google Closure Compiler [experimental]',
	'item_compresseur_css' => 'Enable stylesheets compression (CSS)',
	'item_compresseur_js' => 'Enable scripts compression (javascript)',

	// L
	'label_url_statique_ressources' => 'URL resources',

	// T
	'texte_compacter_avertissement' => 'Be careful not to activate these options during site development, as compressed elements are difficult to read and debug.',
	'texte_compacter_script_css' => 'SPIP can compact Javascript files and CSS stylesheets and save them as static files. This makes the site display faster on browsers.',
	'titre_compacter_script_css' => 'Compression of scripts and CSS'
);

?>
